from forge import protos
from forge.config import config
from forge.utils import utils

stub = protos.ChainRpcStub(config.get_grpc_channel())


def create_tx(itx=None, from_address='',
              wallet=None, token=None, req=None, nonce=1,
              ):
    """RPC call to create transaction.

    Parameters
    ----------
    req : RequestCreateTx
    itx : google.protobuf.An
    from_address : string
    nonce : uint64
    wallet : WalletInfo
    token : string

    Returns
    -------
    ResponseCreateTx

    """

    if req is not None:
        return stub.create_tx(req)
    else:
        req_kwargs = {
            'itx': itx,
            'from': from_address,
            'nonce': nonce,
            'wallet': wallet,
            'token': token,
        }
        return stub.create_tx(protos.RequestCreateTx(**req_kwargs))


def send_tx(
        tx=None, wallet=None, token=None, commit=False, req=None,
):
    """
    RPC call to send transaction.

    Parameters
    ----------
    req: RequestSendTx
    tx : Transaction
    wallet: WalletInfo
    token: string
    commit: bool

    Returns
    -------
    ResponseSendTx

    """
    if req is not None:
        return stub.send_tx(req)
    else:
        req_kwargs = {
            'tx': tx,
            'wallet': wallet,
            'token': token,
            'commit': commit,
        }
        req = protos.RequestSendTx(**req_kwargs)
        return stub.send_tx(req)


def get_tx(tx_hash='', req=None):
    """
    RPC call to get transaction.

    Parameters
    ----------
    req: stream RequestGetTx
    tx_hash: single string or string iterator

    Returns
    -------
    stream  ResponseGetTx

    """

    def to_req(item):
        if isinstance(item, protos.RequestGetTx):
            return item
        else:
            return protos.RequestGetTx(hash=item)

    if req is not None:
        return stub.get_tx(utils.to_iter(to_req, req))
    else:
        return stub.get_tx(utils.to_iter(to_req, tx_hash))


def get_block(height=0, req=None):
    """
    RPC call to get blocks.

    Parameters
    ----------
    req: RequestGetBlock
    height: uint64

    Returns
    -------
    stream ResponseGetBlock

    """

    def to_req(item):
        if isinstance(item, protos.RequestGetBlock):
            return item
        else:
            return protos.RequestGetBlock(height=item)

    if req is not None:
        return stub.get_block(utils.to_iter(to_req, req))
    else:
        return stub.get_block(utils.to_iter(to_req, height))


def search(key='', value='', req=None):
    """

    Parameters
    ----------
    req: RequestSearch
    key: string
    value: string

    Returns
    -------
    ResponseSearch

    """
    if req is not None:
        return stub.search(req)
    else:
        req_kwargs = {
            'key': key,
            'value': value,
        }
        return stub.search(protos.RequestSearch(**req_kwargs))


def get_unconfirmed_tx(req=None, limit=1):
    """

    Parameters
    ----------
    req: RequestGetUnconfirmedTxs
    limit: int

    Returns
    -------
    ResponseGetUnconfirmedTxs

    """
    if req is not None:
        return stub.get_unconfirmed_txs(req)
    else:
        return stub.get_unconfirmed_txs(
            protos.RequestGetUnconfirmedTxs(limit=limit),
        )


def get_chain_info(req=None):
    """

    Parameters
    ----------
    req: RequestGetChainInfo

    Returns
    -------
    ResponseGetChainInfo

    """
    if req is not None:
        return stub.get_chain_info(req)
    else:
        return stub.get_chain_info(protos.RequestGetChainInfo())


def get_net_info(req=None):
    """

    Parameters
    ----------
    req: RequestGetNetInfo

    Returns
    -------
    ResponseGetNetInfo

    """
    if req is not None:
        return stub.get_net_info(req)
    else:
        return stub.get_net_info(protos.RequestGetNetInfo())


def get_validators_info(req=None):
    """

    Parameters
    ----------
    req: RequestGetValidatorsInfo

    Returns
    -------
    ResponseGetValidatorsInfo

    """
    if req is not None:
        return stub.get_validators_info(req)
    else:
        return stub.get_validators_info(
            protos.RequestGetValidatorsInfo(),
        )


def get_config(req=None):
    """

    Parameters
    ----------
    req: RequestGetConfig

    Returns
    -------
    ResponseGetConfig

    """
    if req is not None:
        return stub.get_config(req)
    else:
        return stub.get_config(
            protos.RequestGetConfig(),
        )


def multisig(tx=None, wallet=None, token=None, data=None, req=None):
    if req is not None:
        return stub.multisig(req)
    else:
        req = protos.RequestMultisig(
            tx=tx, wallet=wallet, token=token,
            data=data,
        )
        return stub.multisig(req)


def get_asset_address(
        sender_address='', itx=None,
        wallet_type=None, req=None,
):
    if req is not None:
        return stub.get_asset_address(req)
    else:
        return stub.get_asset_address(
            protos.RequestGetAssetAddress(
                sender_address=sender_address, itx=itx,
                wallet_type=wallet_type,
            ),
        )



from forge import protos


class RpcStatistic:
    def __init__(self, chan):
        self.stub = protos.StatisticRpcStub(chan)

    def list_asset_transactions(self, address, paging=None):
        return self.stub.list_asset_transactions(
            protos.RequestListAssetTransactions(
                address=address,
                paging=paging,
            ),
        )

    def list_transactions(
            self, address_filter, time_filter=None,
            type_filter=None, paging=None,
    ):
        req = protos.RequestListTransactions(
            paging=paging,
            time_filter=time_filter,
            address_filter=address_filter,
            type_filter=type_filter,
        )
        return self.stub.list_transactions(req)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import abi_pb2 as abi__pb2


class ForgeAppRpcStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

        Args:
          channel: A grpc.Channel.
        """
        self.process_one = channel.unary_unary(
            '/forge_abi.ForgeAppRpc/process_one',
            request_serializer=abi__pb2.Request.SerializeToString,
            response_deserializer=abi__pb2.Response.FromString,
        )
        self.process = channel.stream_stream(
            '/forge_abi.ForgeAppRpc/process',
            request_serializer=abi__pb2.Request.SerializeToString,
            response_deserializer=abi__pb2.Response.FromString,
        )


class ForgeAppRpcServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def process_one(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def process(self, request_iterator, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ForgeAppRpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'process_one': grpc.unary_unary_rpc_method_handler(
            servicer.process_one,
            request_deserializer=abi__pb2.Request.FromString,
            response_serializer=abi__pb2.Response.SerializeToString,
        ),
        'process': grpc.stream_stream_rpc_method_handler(
            servicer.process,
            request_deserializer=abi__pb2.Request.FromString,
            response_serializer=abi__pb2.Response.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'forge_abi.ForgeAppRpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))



import logging
import os
import os.path as path
from os.path import expanduser

import grpc
import toml
from deepmerge import Merger

logger = logging.getLogger('forge-config')

default_forge_toml = path.join(path.dirname(__file__), "forge_default.toml")

config = toml.load(default_forge_toml)


def use_config(config_path):
    if path.exists(config_path):
        logger.info("Using config in {}".format(config_path))
        try:
            user_config = toml.load(config_path)

            merger = Merger(
                # strategy for each type
                [
                    (list, ["append"]),
                    (dict, ["merge"]),
                ],
                # fallback strategies for all other types
                ["override"],
                # strategies for conflicted types
                ["override"],
            )
            res_config = toml.load(default_forge_toml)
            merger.merge(res_config, user_config)
            global config
            config = res_config

        except Exception as e:
            logger.error(e, exc_info=True)
            logger.error("Fail to parse toml config in {}".format(config_path))


def __parse_socket(forge_path, forge_socket):
    """

    Parameters
    ----------
    Returns: string
        unix: "unix:///tmp/.forge_test/app/socks/abi.sock"
        tcp: "tcp://127.0.0.1:38210"

    -------

    """
    socket_type = forge_socket.split("://")[0]
    parsed_socket = forge_socket.split("://")[1]
    if socket_type == 'unix':
        socket_target = '/'.join([
            'unix:/',
            forge_path, parsed_socket,
        ])
    else:
        socket_target = forge_socket
    return socket_target


def __parse_socket_grpc(forge_path, forge_socket):
    socket_addr = __parse_socket(forge_path, forge_socket)
    socket_type = socket_addr.split('://')[0]
    if socket_type == 'unix':
        return socket_addr
    elif socket_type == 'tcp':
        return socket_addr.split('://')[1]


# Use Environment FORGE_CONFIG if exists
env_config = os.environ.get('FORGE_CONFIG')
if env_config:
    use_config(env_config)


def get_app_path():
    return expanduser(config['app']['path'])


def get_app_host():
    return config['app']['host']


def get_forge_path():
    return expanduser(config['forge']['path'])


def get_grpc_socket():
    return __parse_socket_grpc(
        get_forge_path(),
        config['forge']['sock_grpc'],
    )


def get_tcp_socket():
    return __parse_socket(
        get_app_path(),
        config['app']['sock_tcp'],
    )


def get_grpc_channel():
    return grpc.insecure_channel(get_grpc_socket())



from .rpc import ForgeRpc
from forge.rpc import chain
from forge.rpc import event
from forge.rpc import file
from forge.rpc import rpc
from forge.rpc import state
from forge.rpc import statistic
from forge.rpc import wallet



from forge import protos
from forge.config import config
from forge.utils import utils

stub = protos.StateRpcStub(config.get_grpc_channel())


def get_account_state(req):
    """
    RPC call to get account state.

    Parameters
    ----------
    req: stream RequestGetAccountState

    Returns
    -------
    stream ResponseGetAccountState

    """

    def to_req(item):
        if isinstance(item, protos.RequestGetAccountState):
            return item
        else:
            kwargs = {
                'address': item.get('address'),
                'keys': item.get('keys', []),
                # 'height': item.get('height', ''),
            }
            return protos.RequestGetAccountState(**kwargs)

    requests = utils.to_iter(to_req, req)

    return stub.get_account_state(requests)


def get_asset_state(req=None):
    """
    RPC call to get asset state.

    Parameters
    ----------
    req: stream RequestGetAssetState

    Returns
    -------
    stream ResponseGetAssetState

    """

    def to_req(item):
        if isinstance(item, protos.RequestGetAssetState):
            return item
        else:
            kwargs = {
                'address': item.get('address'),
                'keys': item.get('keys', []),
                # 'app_hash': item.get('app_hash', ''),
            }
            req = protos.RequestGetAssetState(**kwargs)
            return req

    requests = utils.to_iter(to_req, req)

    return stub.get_asset_state(requests)


def get_stake_state(req=None):
    """
    RPC call to get stake state.

    Parameters
    ----------
    req: stream RequestGetStakeState

    Returns
    -------
    stream ResponseGetChannelState

    """

    def to_req(item):
        if isinstance(item, protos.RequestGetStakeState):
            return item
        else:
            kwargs = {
                'address': item.get('address'),
                'keys': item.get('keys', []),
                # 'app_hash': item.get('app_hash', ''),
            }
            return protos.RequestGetStakeState(**kwargs)

    requests = utils.to_iter(to_req, req)
    return stub.get_stake_state(requests)


def get_forge_state(keys='', app_hash='', req=None):
    """
    RPC call to get forge state.

    Parameters
    ----------
    req: RequestGetForgeState

    Returns
    -------
    ResponseGetForgeState

    """
    if req is not None:
        return stub.get_forge_state(req)
    else:
        req_kwargs = {
            'keys': keys,
            # 'app_hash': app_hash,
        }
        return stub.get_forge_state(
            protos.RequestGetForgeState(**req_kwargs),
        )



import ed25519
import secp256k1


class Signer:
    def __init__(self, name='ed25519'):
        self.signer_type = Ed25519Signer
        if name == 'secp256k1':
            self.signer_type = Secp256k1Signer

        self.keypair = self.signer_type.keypair
        self.sk_to_pk = self.signer_type.sk_to_pk
        self.sign = self.signer_type.sign
        self.verify = self.signer_type.verify


class Ed25519Signer:

    @staticmethod
    def keypair():
        sk, pk = ed25519.create_keypair()
        return sk.to_bytes(), pk.to_bytes()

    @staticmethod
    def sk_to_pk(sk):
        secret_key = ed25519.SigningKey(sk)
        public_key = secret_key.get_verifying_key()
        return public_key.to_bytes()

    @staticmethod
    def sign(data, sk):
        secret_key = ed25519.SigningKey(sk)
        signature = secret_key.sign(data)
        return signature

    @staticmethod
    def verify(data, signature, pk):
        public_key = ed25519.VerifyingKey(pk)
        try:
            public_key.verify(signature, data)
            return True
        except ed25519.BadSignatureError:
            return False


class Secp256k1Signer:

    @staticmethod
    def keypair():
        sk = secp256k1.PrivateKey()
        return sk.private_key, sk.pubkey.serialize()

    @staticmethod
    def sk_to_pk(sk):
        sk = secp256k1.PrivateKey(sk)
        return sk.pubkey.serialize()

    @staticmethod
    def sign(data, sk):
        sk = secp256k1.PrivateKey(sk)
        signature = sk.ecdsa_sign(data)
        return signature

    @staticmethod
    def verify(data, signature, pk):
        pk_object = secp256k1.PublicKey(pubkey=pk, raw=True)
        result = pk_object.ecdsa_verify(data, signature)
        return result



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vendor.proto
import sys

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
_b = sys.version_info[0] < 3 and (
    lambda x: x) or (lambda x: x.encode('latin1'))
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name='vendor.proto',
    package='abci_vendor',
    syntax='proto3',
    serialized_options=None,
    serialized_pb=_b('\n\x0cvendor.proto\x12\x0b\x61\x62\x63i_vendor\x1a\x1fgoogle/protobuf/timestamp.proto\"$\n\x06KVPair\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\"2\n\x07ProofOp\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"*\n\x05Proof\x12!\n\x03ops\x18\x01 \x03(\x0b\x32\x14.abci_vendor.ProofOp\"1\n\x0b\x42lockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03\"!\n\x0e\x45videnceParams\x12\x0f\n\x07max_age\x18\x01 \x01(\x03\"(\n\x0fValidatorParams\x12\x15\n\rpub_key_types\x18\x01 \x03(\t\"\x9a\x01\n\x0f\x43onsensusParams\x12\'\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x18.abci_vendor.BlockParams\x12-\n\x08\x65vidence\x18\x02 \x01(\x0b\x32\x1b.abci_vendor.EvidenceParams\x12/\n\tvalidator\x18\x03 \x01(\x0b\x32\x1c.abci_vendor.ValidatorParams\"E\n\x0eLastCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12$\n\x05votes\x18\x02 \x03(\x0b\x32\x15.abci_vendor.VoteInfo\"%\n\x07Version\x12\r\n\x05\x42lock\x18\x01 \x01(\x04\x12\x0b\n\x03\x41pp\x18\x02 \x01(\x04\"I\n\x07\x42lockID\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x30\n\x0cparts_header\x18\x02 \x01(\x0b\x32\x1a.abci_vendor.PartSetHeader\",\n\rPartSetHeader\x12\r\n\x05total\x18\x01 \x01(\x05\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\"+\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03\"F\n\x0fValidatorUpdate\x12$\n\x07pub_key\x18\x01 \x01(\x0b\x32\x13.abci_vendor.PubKey\x12\r\n\x05power\x18\x02 \x01(\x03\"P\n\x08VoteInfo\x12)\n\tvalidator\x18\x01 \x01(\x0b\x32\x16.abci_vendor.Validator\x12\x19\n\x11signed_last_block\x18\x02 \x01(\x08\"$\n\x06PubKey\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\x99\x01\n\x08\x45vidence\x12\x0c\n\x04type\x18\x01 \x01(\t\x12)\n\tvalidator\x18\x02 \x01(\x0b\x32\x16.abci_vendor.Validator\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12(\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12total_voting_power\x18\x05 \x01(\x03\"\xa6\x03\n\x06Header\x12%\n\x07version\x18\x01 \x01(\x0b\x32\x14.abci_vendor.Version\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12(\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07num_txs\x18\x05 \x01(\x03\x12\x11\n\ttotal_txs\x18\x06 \x01(\x03\x12+\n\rlast_block_id\x18\x07 \x01(\x0b\x32\x14.abci_vendor.BlockID\x12\x18\n\x10last_commit_hash\x18\x08 \x01(\x0c\x12\x11\n\tdata_hash\x18\t \x01(\x0c\x12\x17\n\x0fvalidators_hash\x18\n \x01(\x0c\x12\x1c\n\x14next_validators_hash\x18\x0b \x01(\x0c\x12\x16\n\x0e\x63onsensus_hash\x18\x0c \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\r \x01(\x0c\x12\x19\n\x11last_results_hash\x18\x0e \x01(\x0c\x12\x15\n\revidence_hash\x18\x0f \x01(\x0c\x12\x18\n\x10proposer_address\x18\x10 \x01(\x0c\"\x1e\n\x0bRequestEcho\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0e\n\x0cRequestFlush\"J\n\x0bRequestInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rblock_version\x18\x02 \x01(\x04\x12\x13\n\x0bp2p_version\x18\x03 \x01(\x04\".\n\x10RequestSetOption\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xd1\x01\n\x10RequestInitChain\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\x12\x36\n\x10\x63onsensus_params\x18\x03 \x01(\x0b\x32\x1c.abci_vendor.ConsensusParams\x12\x30\n\nvalidators\x18\x04 \x03(\x0b\x32\x1c.abci_vendor.ValidatorUpdate\x12\x17\n\x0f\x61pp_state_bytes\x18\x05 \x01(\x0c\"I\n\x0cRequestQuery\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08\"\xb2\x01\n\x11RequestBeginBlock\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12#\n\x06header\x18\x02 \x01(\x0b\x32\x13.abci_vendor.Header\x12\x35\n\x10last_commit_info\x18\x03 \x01(\x0b\x32\x1b.abci_vendor.LastCommitInfo\x12\x33\n\x14\x62yzantine_validators\x18\x04 \x03(\x0b\x32\x15.abci_vendor.Evidence\"\x1c\n\x0eRequestCheckTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"\x1e\n\x10RequestDeliverTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"!\n\x0fRequestEndBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03\"\x0f\n\rRequestCommit\"\xa6\x04\n\x07Request\x12(\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x18.abci_vendor.RequestEchoH\x00\x12*\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x19.abci_vendor.RequestFlushH\x00\x12(\n\x04info\x18\x04 \x01(\x0b\x32\x18.abci_vendor.RequestInfoH\x00\x12\x33\n\nset_option\x18\x05 \x01(\x0b\x32\x1d.abci_vendor.RequestSetOptionH\x00\x12\x33\n\ninit_chain\x18\x06 \x01(\x0b\x32\x1d.abci_vendor.RequestInitChainH\x00\x12*\n\x05query\x18\x07 \x01(\x0b\x32\x19.abci_vendor.RequestQueryH\x00\x12\x35\n\x0b\x62\x65gin_block\x18\x08 \x01(\x0b\x32\x1e.abci_vendor.RequestBeginBlockH\x00\x12/\n\x08\x63heck_tx\x18\t \x01(\x0b\x32\x1b.abci_vendor.RequestCheckTxH\x00\x12\x33\n\ndeliver_tx\x18\x13 \x01(\x0b\x32\x1d.abci_vendor.RequestDeliverTxH\x00\x12\x31\n\tend_block\x18\x0b \x01(\x0b\x32\x1c.abci_vendor.RequestEndBlockH\x00\x12,\n\x06\x63ommit\x18\x0c \x01(\x0b\x32\x1a.abci_vendor.RequestCommitH\x00\x42\x07\n\x05value\"\"\n\x11ResponseException\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\x1f\n\x0cResponseEcho\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x0f\n\rResponseFlush\"z\n\x0cResponseInfo\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x03 \x01(\x04\x12\x19\n\x11last_block_height\x18\x04 \x01(\x03\x12\x1b\n\x13last_block_app_hash\x18\x05 \x01(\x0c\"<\n\x11ResponseSetOption\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\"}\n\x11ResponseInitChain\x12\x36\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\x1c.abci_vendor.ConsensusParams\x12\x30\n\nvalidators\x18\x02 \x03(\x0b\x32\x1c.abci_vendor.ValidatorUpdate\"\xa9\x01\n\rResponseQuery\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12!\n\x05proof\x18\x08 \x01(\x0b\x32\x12.abci_vendor.Proof\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\t\"7\n\x12ResponseBeginBlock\x12!\n\x04tags\x18\x01 \x03(\x0b\x32\x13.abci_vendor.KVPair\"\xa4\x01\n\x0fResponseCheckTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x12\n\ngas_wanted\x18\x05 \x01(\x03\x12\x10\n\x08gas_used\x18\x06 \x01(\x03\x12!\n\x04tags\x18\x07 \x03(\x0b\x32\x13.abci_vendor.KVPair\x12\x11\n\tcodespace\x18\x08 \x01(\t\"\xa6\x01\n\x11ResponseDeliverTx\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x12\n\ngas_wanted\x18\x05 \x01(\x03\x12\x10\n\x08gas_used\x18\x06 \x01(\x03\x12!\n\x04tags\x18\x07 \x03(\x0b\x32\x13.abci_vendor.KVPair\x12\x11\n\tcodespace\x18\x08 \x01(\t\"\xad\x01\n\x10ResponseEndBlock\x12\x37\n\x11validator_updates\x18\x01 \x03(\x0b\x32\x1c.abci_vendor.ValidatorUpdate\x12=\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32\x1c.abci_vendor.ConsensusParams\x12!\n\x04tags\x18\x03 \x03(\x0b\x32\x13.abci_vendor.KVPair\"\x1e\n\x0eResponseCommit\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\xe7\x04\n\x08Response\x12\x33\n\texception\x18\x01 \x01(\x0b\x32\x1e.abci_vendor.ResponseExceptionH\x00\x12)\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x19.abci_vendor.ResponseEchoH\x00\x12+\n\x05\x66lush\x18\x03 \x01(\x0b\x32\x1a.abci_vendor.ResponseFlushH\x00\x12)\n\x04info\x18\x04 \x01(\x0b\x32\x19.abci_vendor.ResponseInfoH\x00\x12\x34\n\nset_option\x18\x05 \x01(\x0b\x32\x1e.abci_vendor.ResponseSetOptionH\x00\x12\x34\n\ninit_chain\x18\x06 \x01(\x0b\x32\x1e.abci_vendor.ResponseInitChainH\x00\x12+\n\x05query\x18\x07 \x01(\x0b\x32\x1a.abci_vendor.ResponseQueryH\x00\x12\x36\n\x0b\x62\x65gin_block\x18\x08 \x01(\x0b\x32\x1f.abci_vendor.ResponseBeginBlockH\x00\x12\x30\n\x08\x63heck_tx\x18\t \x01(\x0b\x32\x1c.abci_vendor.ResponseCheckTxH\x00\x12\x34\n\ndeliver_tx\x18\n \x01(\x0b\x32\x1e.abci_vendor.ResponseDeliverTxH\x00\x12\x32\n\tend_block\x18\x0b \x01(\x0b\x32\x1d.abci_vendor.ResponseEndBlockH\x00\x12-\n\x06\x63ommit\x18\x0c \x01(\x0b\x32\x1b.abci_vendor.ResponseCommitH\x00\x42\x07\n\x05value\"\r\n\x0bRequestPing\" \n\x12RequestBroadcastTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\"\x0e\n\x0cResponsePing\"y\n\x13ResponseBroadcastTx\x12.\n\x08\x63heck_tx\x18\x01 \x01(\x0b\x32\x1c.abci_vendor.ResponseCheckTx\x12\x32\n\ndeliver_tx\x18\x02 \x01(\x0b\x32\x1e.abci_vendor.ResponseDeliverTx2\x90\x06\n\x0f\x41\x42\x43IApplication\x12;\n\x04\x45\x63ho\x12\x18.abci_vendor.RequestEcho\x1a\x19.abci_vendor.ResponseEcho\x12>\n\x05\x46lush\x12\x19.abci_vendor.RequestFlush\x1a\x1a.abci_vendor.ResponseFlush\x12;\n\x04Info\x12\x18.abci_vendor.RequestInfo\x1a\x19.abci_vendor.ResponseInfo\x12J\n\tSetOption\x12\x1d.abci_vendor.RequestSetOption\x1a\x1e.abci_vendor.ResponseSetOption\x12J\n\tDeliverTx\x12\x1d.abci_vendor.RequestDeliverTx\x1a\x1e.abci_vendor.ResponseDeliverTx\x12\x44\n\x07\x43heckTx\x12\x1b.abci_vendor.RequestCheckTx\x1a\x1c.abci_vendor.ResponseCheckTx\x12>\n\x05Query\x12\x19.abci_vendor.RequestQuery\x1a\x1a.abci_vendor.ResponseQuery\x12\x41\n\x06\x43ommit\x12\x1a.abci_vendor.RequestCommit\x1a\x1b.abci_vendor.ResponseCommit\x12J\n\tInitChain\x12\x1d.abci_vendor.RequestInitChain\x1a\x1e.abci_vendor.ResponseInitChain\x12M\n\nBeginBlock\x12\x1e.abci_vendor.RequestBeginBlock\x1a\x1f.abci_vendor.ResponseBeginBlock\x12G\n\x08\x45ndBlock\x12\x1c.abci_vendor.RequestEndBlock\x1a\x1d.abci_vendor.ResponseEndBlockb\x06proto3'),
    dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR, ])


_KVPAIR = _descriptor.Descriptor(
    name='KVPair',
    full_name='abci_vendor.KVPair',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='abci_vendor.KVPair.key', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='value', full_name='abci_vendor.KVPair.value', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=62,
    serialized_end=98,
)


_PROOFOP = _descriptor.Descriptor(
    name='ProofOp',
    full_name='abci_vendor.ProofOp',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='abci_vendor.ProofOp.type', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='key', full_name='abci_vendor.ProofOp.key', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='data', full_name='abci_vendor.ProofOp.data', index=2,
            number=3, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=100,
    serialized_end=150,
)


_PROOF = _descriptor.Descriptor(
    name='Proof',
    full_name='abci_vendor.Proof',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='ops', full_name='abci_vendor.Proof.ops', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=152,
    serialized_end=194,
)


_BLOCKPARAMS = _descriptor.Descriptor(
    name='BlockParams',
    full_name='abci_vendor.BlockParams',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='max_bytes', full_name='abci_vendor.BlockParams.max_bytes', index=0,
            number=1, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='max_gas', full_name='abci_vendor.BlockParams.max_gas', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=196,
    serialized_end=245,
)


_EVIDENCEPARAMS = _descriptor.Descriptor(
    name='EvidenceParams',
    full_name='abci_vendor.EvidenceParams',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='max_age', full_name='abci_vendor.EvidenceParams.max_age', index=0,
            number=1, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=247,
    serialized_end=280,
)


_VALIDATORPARAMS = _descriptor.Descriptor(
    name='ValidatorParams',
    full_name='abci_vendor.ValidatorParams',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='pub_key_types', full_name='abci_vendor.ValidatorParams.pub_key_types', index=0,
            number=1, type=9, cpp_type=9, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=282,
    serialized_end=322,
)


_CONSENSUSPARAMS = _descriptor.Descriptor(
    name='ConsensusParams',
    full_name='abci_vendor.ConsensusParams',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='block', full_name='abci_vendor.ConsensusParams.block', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='evidence', full_name='abci_vendor.ConsensusParams.evidence', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='validator', full_name='abci_vendor.ConsensusParams.validator', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=325,
    serialized_end=479,
)


_LASTCOMMITINFO = _descriptor.Descriptor(
    name='LastCommitInfo',
    full_name='abci_vendor.LastCommitInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='round', full_name='abci_vendor.LastCommitInfo.round', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='votes', full_name='abci_vendor.LastCommitInfo.votes', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=481,
    serialized_end=550,
)


_VERSION = _descriptor.Descriptor(
    name='Version',
    full_name='abci_vendor.Version',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='Block', full_name='abci_vendor.Version.Block', index=0,
            number=1, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='App', full_name='abci_vendor.Version.App', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=552,
    serialized_end=589,
)


_BLOCKID = _descriptor.Descriptor(
    name='BlockID',
    full_name='abci_vendor.BlockID',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='hash', full_name='abci_vendor.BlockID.hash', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='parts_header', full_name='abci_vendor.BlockID.parts_header', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=591,
    serialized_end=664,
)


_PARTSETHEADER = _descriptor.Descriptor(
    name='PartSetHeader',
    full_name='abci_vendor.PartSetHeader',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='total', full_name='abci_vendor.PartSetHeader.total', index=0,
            number=1, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='hash', full_name='abci_vendor.PartSetHeader.hash', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=666,
    serialized_end=710,
)


_VALIDATOR = _descriptor.Descriptor(
    name='Validator',
    full_name='abci_vendor.Validator',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='address', full_name='abci_vendor.Validator.address', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='power', full_name='abci_vendor.Validator.power', index=1,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=712,
    serialized_end=755,
)


_VALIDATORUPDATE = _descriptor.Descriptor(
    name='ValidatorUpdate',
    full_name='abci_vendor.ValidatorUpdate',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='pub_key', full_name='abci_vendor.ValidatorUpdate.pub_key', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='power', full_name='abci_vendor.ValidatorUpdate.power', index=1,
            number=2, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=757,
    serialized_end=827,
)


_VOTEINFO = _descriptor.Descriptor(
    name='VoteInfo',
    full_name='abci_vendor.VoteInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='validator', full_name='abci_vendor.VoteInfo.validator', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='signed_last_block', full_name='abci_vendor.VoteInfo.signed_last_block', index=1,
            number=2, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=829,
    serialized_end=909,
)


_PUBKEY = _descriptor.Descriptor(
    name='PubKey',
    full_name='abci_vendor.PubKey',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='abci_vendor.PubKey.type', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='data', full_name='abci_vendor.PubKey.data', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=911,
    serialized_end=947,
)


_EVIDENCE = _descriptor.Descriptor(
    name='Evidence',
    full_name='abci_vendor.Evidence',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='type', full_name='abci_vendor.Evidence.type', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='validator', full_name='abci_vendor.Evidence.validator', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='height', full_name='abci_vendor.Evidence.height', index=2,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='time', full_name='abci_vendor.Evidence.time', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='total_voting_power', full_name='abci_vendor.Evidence.total_voting_power', index=4,
            number=5, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=950,
    serialized_end=1103,
)


_HEADER = _descriptor.Descriptor(
    name='Header',
    full_name='abci_vendor.Header',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='version', full_name='abci_vendor.Header.version', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='chain_id', full_name='abci_vendor.Header.chain_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='height', full_name='abci_vendor.Header.height', index=2,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='time', full_name='abci_vendor.Header.time', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='num_txs', full_name='abci_vendor.Header.num_txs', index=4,
            number=5, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='total_txs', full_name='abci_vendor.Header.total_txs', index=5,
            number=6, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='last_block_id', full_name='abci_vendor.Header.last_block_id', index=6,
            number=7, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='last_commit_hash', full_name='abci_vendor.Header.last_commit_hash', index=7,
            number=8, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='data_hash', full_name='abci_vendor.Header.data_hash', index=8,
            number=9, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='validators_hash', full_name='abci_vendor.Header.validators_hash', index=9,
            number=10, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='next_validators_hash', full_name='abci_vendor.Header.next_validators_hash', index=10,
            number=11, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='consensus_hash', full_name='abci_vendor.Header.consensus_hash', index=11,
            number=12, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='app_hash', full_name='abci_vendor.Header.app_hash', index=12,
            number=13, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='last_results_hash', full_name='abci_vendor.Header.last_results_hash', index=13,
            number=14, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='evidence_hash', full_name='abci_vendor.Header.evidence_hash', index=14,
            number=15, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='proposer_address', full_name='abci_vendor.Header.proposer_address', index=15,
            number=16, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1106,
    serialized_end=1528,
)


_REQUESTECHO = _descriptor.Descriptor(
    name='RequestEcho',
    full_name='abci_vendor.RequestEcho',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='message', full_name='abci_vendor.RequestEcho.message', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1530,
    serialized_end=1560,
)


_REQUESTFLUSH = _descriptor.Descriptor(
    name='RequestFlush',
    full_name='abci_vendor.RequestFlush',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1562,
    serialized_end=1576,
)


_REQUESTINFO = _descriptor.Descriptor(
    name='RequestInfo',
    full_name='abci_vendor.RequestInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='version', full_name='abci_vendor.RequestInfo.version', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='block_version', full_name='abci_vendor.RequestInfo.block_version', index=1,
            number=2, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='p2p_version', full_name='abci_vendor.RequestInfo.p2p_version', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1578,
    serialized_end=1652,
)


_REQUESTSETOPTION = _descriptor.Descriptor(
    name='RequestSetOption',
    full_name='abci_vendor.RequestSetOption',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='key', full_name='abci_vendor.RequestSetOption.key', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='value', full_name='abci_vendor.RequestSetOption.value', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1654,
    serialized_end=1700,
)


_REQUESTINITCHAIN = _descriptor.Descriptor(
    name='RequestInitChain',
    full_name='abci_vendor.RequestInitChain',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='time', full_name='abci_vendor.RequestInitChain.time', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='chain_id', full_name='abci_vendor.RequestInitChain.chain_id', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='consensus_params', full_name='abci_vendor.RequestInitChain.consensus_params', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='validators', full_name='abci_vendor.RequestInitChain.validators', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='app_state_bytes', full_name='abci_vendor.RequestInitChain.app_state_bytes', index=4,
            number=5, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1703,
    serialized_end=1912,
)


_REQUESTQUERY = _descriptor.Descriptor(
    name='RequestQuery',
    full_name='abci_vendor.RequestQuery',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='data', full_name='abci_vendor.RequestQuery.data', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='path', full_name='abci_vendor.RequestQuery.path', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='height', full_name='abci_vendor.RequestQuery.height', index=2,
            number=3, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='prove', full_name='abci_vendor.RequestQuery.prove', index=3,
            number=4, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1914,
    serialized_end=1987,
)


_REQUESTBEGINBLOCK = _descriptor.Descriptor(
    name='RequestBeginBlock',
    full_name='abci_vendor.RequestBeginBlock',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='hash', full_name='abci_vendor.RequestBeginBlock.hash', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='header', full_name='abci_vendor.RequestBeginBlock.header', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='last_commit_info', full_name='abci_vendor.RequestBeginBlock.last_commit_info', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='byzantine_validators', full_name='abci_vendor.RequestBeginBlock.byzantine_validators', index=3,
            number=4, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=1990,
    serialized_end=2168,
)


_REQUESTCHECKTX = _descriptor.Descriptor(
    name='RequestCheckTx',
    full_name='abci_vendor.RequestCheckTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx', full_name='abci_vendor.RequestCheckTx.tx', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2170,
    serialized_end=2198,
)


_REQUESTDELIVERTX = _descriptor.Descriptor(
    name='RequestDeliverTx',
    full_name='abci_vendor.RequestDeliverTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx', full_name='abci_vendor.RequestDeliverTx.tx', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2200,
    serialized_end=2230,
)


_REQUESTENDBLOCK = _descriptor.Descriptor(
    name='RequestEndBlock',
    full_name='abci_vendor.RequestEndBlock',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='height', full_name='abci_vendor.RequestEndBlock.height', index=0,
            number=1, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2232,
    serialized_end=2265,
)


_REQUESTCOMMIT = _descriptor.Descriptor(
    name='RequestCommit',
    full_name='abci_vendor.RequestCommit',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2267,
    serialized_end=2282,
)


_REQUEST = _descriptor.Descriptor(
    name='Request',
    full_name='abci_vendor.Request',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='echo', full_name='abci_vendor.Request.echo', index=0,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='flush', full_name='abci_vendor.Request.flush', index=1,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='info', full_name='abci_vendor.Request.info', index=2,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='set_option', full_name='abci_vendor.Request.set_option', index=3,
            number=5, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_chain', full_name='abci_vendor.Request.init_chain', index=4,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='query', full_name='abci_vendor.Request.query', index=5,
            number=7, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='begin_block', full_name='abci_vendor.Request.begin_block', index=6,
            number=8, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='check_tx', full_name='abci_vendor.Request.check_tx', index=7,
            number=9, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='deliver_tx', full_name='abci_vendor.Request.deliver_tx', index=8,
            number=19, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_block', full_name='abci_vendor.Request.end_block', index=9,
            number=11, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commit', full_name='abci_vendor.Request.commit', index=10,
            number=12, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='value', full_name='abci_vendor.Request.value',
            index=0, containing_type=None, fields=[]),
    ],
    serialized_start=2285,
    serialized_end=2835,
)


_RESPONSEEXCEPTION = _descriptor.Descriptor(
    name='ResponseException',
    full_name='abci_vendor.ResponseException',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='error', full_name='abci_vendor.ResponseException.error', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2837,
    serialized_end=2871,
)


_RESPONSEECHO = _descriptor.Descriptor(
    name='ResponseEcho',
    full_name='abci_vendor.ResponseEcho',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='message', full_name='abci_vendor.ResponseEcho.message', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2873,
    serialized_end=2904,
)


_RESPONSEFLUSH = _descriptor.Descriptor(
    name='ResponseFlush',
    full_name='abci_vendor.ResponseFlush',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2906,
    serialized_end=2921,
)


_RESPONSEINFO = _descriptor.Descriptor(
    name='ResponseInfo',
    full_name='abci_vendor.ResponseInfo',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='data', full_name='abci_vendor.ResponseInfo.data', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='version', full_name='abci_vendor.ResponseInfo.version', index=1,
            number=2, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='app_version', full_name='abci_vendor.ResponseInfo.app_version', index=2,
            number=3, type=4, cpp_type=4, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='last_block_height', full_name='abci_vendor.ResponseInfo.last_block_height', index=3,
            number=4, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='last_block_app_hash', full_name='abci_vendor.ResponseInfo.last_block_app_hash', index=4,
            number=5, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=2923,
    serialized_end=3045,
)


_RESPONSESETOPTION = _descriptor.Descriptor(
    name='ResponseSetOption',
    full_name='abci_vendor.ResponseSetOption',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='abci_vendor.ResponseSetOption.code', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='log', full_name='abci_vendor.ResponseSetOption.log', index=1,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='info', full_name='abci_vendor.ResponseSetOption.info', index=2,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3047,
    serialized_end=3107,
)


_RESPONSEINITCHAIN = _descriptor.Descriptor(
    name='ResponseInitChain',
    full_name='abci_vendor.ResponseInitChain',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='consensus_params', full_name='abci_vendor.ResponseInitChain.consensus_params', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='validators', full_name='abci_vendor.ResponseInitChain.validators', index=1,
            number=2, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3109,
    serialized_end=3234,
)


_RESPONSEQUERY = _descriptor.Descriptor(
    name='ResponseQuery',
    full_name='abci_vendor.ResponseQuery',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='abci_vendor.ResponseQuery.code', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='log', full_name='abci_vendor.ResponseQuery.log', index=1,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='info', full_name='abci_vendor.ResponseQuery.info', index=2,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='index', full_name='abci_vendor.ResponseQuery.index', index=3,
            number=5, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='key', full_name='abci_vendor.ResponseQuery.key', index=4,
            number=6, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='value', full_name='abci_vendor.ResponseQuery.value', index=5,
            number=7, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='proof', full_name='abci_vendor.ResponseQuery.proof', index=6,
            number=8, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='height', full_name='abci_vendor.ResponseQuery.height', index=7,
            number=9, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='codespace', full_name='abci_vendor.ResponseQuery.codespace', index=8,
            number=10, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3237,
    serialized_end=3406,
)


_RESPONSEBEGINBLOCK = _descriptor.Descriptor(
    name='ResponseBeginBlock',
    full_name='abci_vendor.ResponseBeginBlock',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tags', full_name='abci_vendor.ResponseBeginBlock.tags', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3408,
    serialized_end=3463,
)


_RESPONSECHECKTX = _descriptor.Descriptor(
    name='ResponseCheckTx',
    full_name='abci_vendor.ResponseCheckTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='abci_vendor.ResponseCheckTx.code', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='data', full_name='abci_vendor.ResponseCheckTx.data', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='log', full_name='abci_vendor.ResponseCheckTx.log', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='info', full_name='abci_vendor.ResponseCheckTx.info', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='gas_wanted', full_name='abci_vendor.ResponseCheckTx.gas_wanted', index=4,
            number=5, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='gas_used', full_name='abci_vendor.ResponseCheckTx.gas_used', index=5,
            number=6, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='tags', full_name='abci_vendor.ResponseCheckTx.tags', index=6,
            number=7, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='codespace', full_name='abci_vendor.ResponseCheckTx.codespace', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3466,
    serialized_end=3630,
)


_RESPONSEDELIVERTX = _descriptor.Descriptor(
    name='ResponseDeliverTx',
    full_name='abci_vendor.ResponseDeliverTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='code', full_name='abci_vendor.ResponseDeliverTx.code', index=0,
            number=1, type=13, cpp_type=3, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='data', full_name='abci_vendor.ResponseDeliverTx.data', index=1,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='log', full_name='abci_vendor.ResponseDeliverTx.log', index=2,
            number=3, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='info', full_name='abci_vendor.ResponseDeliverTx.info', index=3,
            number=4, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='gas_wanted', full_name='abci_vendor.ResponseDeliverTx.gas_wanted', index=4,
            number=5, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='gas_used', full_name='abci_vendor.ResponseDeliverTx.gas_used', index=5,
            number=6, type=3, cpp_type=2, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='tags', full_name='abci_vendor.ResponseDeliverTx.tags', index=6,
            number=7, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='codespace', full_name='abci_vendor.ResponseDeliverTx.codespace', index=7,
            number=8, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=_b("").decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3633,
    serialized_end=3799,
)


_RESPONSEENDBLOCK = _descriptor.Descriptor(
    name='ResponseEndBlock',
    full_name='abci_vendor.ResponseEndBlock',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='validator_updates', full_name='abci_vendor.ResponseEndBlock.validator_updates', index=0,
            number=1, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='consensus_param_updates', full_name='abci_vendor.ResponseEndBlock.consensus_param_updates', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='tags', full_name='abci_vendor.ResponseEndBlock.tags', index=2,
            number=3, type=11, cpp_type=10, label=3,
            has_default_value=False, default_value=[],
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3802,
    serialized_end=3975,
)


_RESPONSECOMMIT = _descriptor.Descriptor(
    name='ResponseCommit',
    full_name='abci_vendor.ResponseCommit',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='data', full_name='abci_vendor.ResponseCommit.data', index=0,
            number=2, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=3977,
    serialized_end=4007,
)


_RESPONSE = _descriptor.Descriptor(
    name='Response',
    full_name='abci_vendor.Response',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='exception', full_name='abci_vendor.Response.exception', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='echo', full_name='abci_vendor.Response.echo', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='flush', full_name='abci_vendor.Response.flush', index=2,
            number=3, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='info', full_name='abci_vendor.Response.info', index=3,
            number=4, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='set_option', full_name='abci_vendor.Response.set_option', index=4,
            number=5, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='init_chain', full_name='abci_vendor.Response.init_chain', index=5,
            number=6, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='query', full_name='abci_vendor.Response.query', index=6,
            number=7, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='begin_block', full_name='abci_vendor.Response.begin_block', index=7,
            number=8, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='check_tx', full_name='abci_vendor.Response.check_tx', index=8,
            number=9, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='deliver_tx', full_name='abci_vendor.Response.deliver_tx', index=9,
            number=10, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='end_block', full_name='abci_vendor.Response.end_block', index=10,
            number=11, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='commit', full_name='abci_vendor.Response.commit', index=11,
            number=12, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='value', full_name='abci_vendor.Response.value',
            index=0, containing_type=None, fields=[]),
    ],
    serialized_start=4010,
    serialized_end=4625,
)


_REQUESTPING = _descriptor.Descriptor(
    name='RequestPing',
    full_name='abci_vendor.RequestPing',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4627,
    serialized_end=4640,
)


_REQUESTBROADCASTTX = _descriptor.Descriptor(
    name='RequestBroadcastTx',
    full_name='abci_vendor.RequestBroadcastTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='tx', full_name='abci_vendor.RequestBroadcastTx.tx', index=0,
            number=1, type=12, cpp_type=9, label=1,
            has_default_value=False, default_value=_b(""),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4642,
    serialized_end=4674,
)


_RESPONSEPING = _descriptor.Descriptor(
    name='ResponsePing',
    full_name='abci_vendor.ResponsePing',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4676,
    serialized_end=4690,
)


_RESPONSEBROADCASTTX = _descriptor.Descriptor(
    name='ResponseBroadcastTx',
    full_name='abci_vendor.ResponseBroadcastTx',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='check_tx', full_name='abci_vendor.ResponseBroadcastTx.check_tx', index=0,
            number=1, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='deliver_tx', full_name='abci_vendor.ResponseBroadcastTx.deliver_tx', index=1,
            number=2, type=11, cpp_type=10, label=1,
            has_default_value=False, default_value=None,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=4692,
    serialized_end=4813,
)

_PROOF.fields_by_name['ops'].message_type = _PROOFOP
_CONSENSUSPARAMS.fields_by_name['block'].message_type = _BLOCKPARAMS
_CONSENSUSPARAMS.fields_by_name['evidence'].message_type = _EVIDENCEPARAMS
_CONSENSUSPARAMS.fields_by_name['validator'].message_type = _VALIDATORPARAMS
_LASTCOMMITINFO.fields_by_name['votes'].message_type = _VOTEINFO
_BLOCKID.fields_by_name['parts_header'].message_type = _PARTSETHEADER
_VALIDATORUPDATE.fields_by_name['pub_key'].message_type = _PUBKEY
_VOTEINFO.fields_by_name['validator'].message_type = _VALIDATOR
_EVIDENCE.fields_by_name['validator'].message_type = _VALIDATOR
_EVIDENCE.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HEADER.fields_by_name['version'].message_type = _VERSION
_HEADER.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HEADER.fields_by_name['last_block_id'].message_type = _BLOCKID
_REQUESTINITCHAIN.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REQUESTINITCHAIN.fields_by_name['consensus_params'].message_type = _CONSENSUSPARAMS
_REQUESTINITCHAIN.fields_by_name['validators'].message_type = _VALIDATORUPDATE
_REQUESTBEGINBLOCK.fields_by_name['header'].message_type = _HEADER
_REQUESTBEGINBLOCK.fields_by_name['last_commit_info'].message_type = _LASTCOMMITINFO
_REQUESTBEGINBLOCK.fields_by_name['byzantine_validators'].message_type = _EVIDENCE
_REQUEST.fields_by_name['echo'].message_type = _REQUESTECHO
_REQUEST.fields_by_name['flush'].message_type = _REQUESTFLUSH
_REQUEST.fields_by_name['info'].message_type = _REQUESTINFO
_REQUEST.fields_by_name['set_option'].message_type = _REQUESTSETOPTION
_REQUEST.fields_by_name['init_chain'].message_type = _REQUESTINITCHAIN
_REQUEST.fields_by_name['query'].message_type = _REQUESTQUERY
_REQUEST.fields_by_name['begin_block'].message_type = _REQUESTBEGINBLOCK
_REQUEST.fields_by_name['check_tx'].message_type = _REQUESTCHECKTX
_REQUEST.fields_by_name['deliver_tx'].message_type = _REQUESTDELIVERTX
_REQUEST.fields_by_name['end_block'].message_type = _REQUESTENDBLOCK
_REQUEST.fields_by_name['commit'].message_type = _REQUESTCOMMIT
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['echo'])
_REQUEST.fields_by_name['echo'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['flush'])
_REQUEST.fields_by_name['flush'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['info'])
_REQUEST.fields_by_name['info'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['set_option'])
_REQUEST.fields_by_name['set_option'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['init_chain'])
_REQUEST.fields_by_name['init_chain'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['query'])
_REQUEST.fields_by_name['query'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['begin_block'])
_REQUEST.fields_by_name['begin_block'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['check_tx'])
_REQUEST.fields_by_name['check_tx'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['deliver_tx'])
_REQUEST.fields_by_name['deliver_tx'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['end_block'])
_REQUEST.fields_by_name['end_block'].containing_oneof = _REQUEST.oneofs_by_name['value']
_REQUEST.oneofs_by_name['value'].fields.append(
    _REQUEST.fields_by_name['commit'])
_REQUEST.fields_by_name['commit'].containing_oneof = _REQUEST.oneofs_by_name['value']
_RESPONSEINITCHAIN.fields_by_name['consensus_params'].message_type = _CONSENSUSPARAMS
_RESPONSEINITCHAIN.fields_by_name['validators'].message_type = _VALIDATORUPDATE
_RESPONSEQUERY.fields_by_name['proof'].message_type = _PROOF
_RESPONSEBEGINBLOCK.fields_by_name['tags'].message_type = _KVPAIR
_RESPONSECHECKTX.fields_by_name['tags'].message_type = _KVPAIR
_RESPONSEDELIVERTX.fields_by_name['tags'].message_type = _KVPAIR
_RESPONSEENDBLOCK.fields_by_name['validator_updates'].message_type = _VALIDATORUPDATE
_RESPONSEENDBLOCK.fields_by_name['consensus_param_updates'].message_type = _CONSENSUSPARAMS
_RESPONSEENDBLOCK.fields_by_name['tags'].message_type = _KVPAIR
_RESPONSE.fields_by_name['exception'].message_type = _RESPONSEEXCEPTION
_RESPONSE.fields_by_name['echo'].message_type = _RESPONSEECHO
_RESPONSE.fields_by_name['flush'].message_type = _RESPONSEFLUSH
_RESPONSE.fields_by_name['info'].message_type = _RESPONSEINFO
_RESPONSE.fields_by_name['set_option'].message_type = _RESPONSESETOPTION
_RESPONSE.fields_by_name['init_chain'].message_type = _RESPONSEINITCHAIN
_RESPONSE.fields_by_name['query'].message_type = _RESPONSEQUERY
_RESPONSE.fields_by_name['begin_block'].message_type = _RESPONSEBEGINBLOCK
_RESPONSE.fields_by_name['check_tx'].message_type = _RESPONSECHECKTX
_RESPONSE.fields_by_name['deliver_tx'].message_type = _RESPONSEDELIVERTX
_RESPONSE.fields_by_name['end_block'].message_type = _RESPONSEENDBLOCK
_RESPONSE.fields_by_name['commit'].message_type = _RESPONSECOMMIT
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['exception'])
_RESPONSE.fields_by_name['exception'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['echo'])
_RESPONSE.fields_by_name['echo'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['flush'])
_RESPONSE.fields_by_name['flush'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['info'])
_RESPONSE.fields_by_name['info'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['set_option'])
_RESPONSE.fields_by_name['set_option'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['init_chain'])
_RESPONSE.fields_by_name['init_chain'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['query'])
_RESPONSE.fields_by_name['query'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['begin_block'])
_RESPONSE.fields_by_name['begin_block'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['check_tx'])
_RESPONSE.fields_by_name['check_tx'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['deliver_tx'])
_RESPONSE.fields_by_name['deliver_tx'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['end_block'])
_RESPONSE.fields_by_name['end_block'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSE.oneofs_by_name['value'].fields.append(
    _RESPONSE.fields_by_name['commit'])
_RESPONSE.fields_by_name['commit'].containing_oneof = _RESPONSE.oneofs_by_name['value']
_RESPONSEBROADCASTTX.fields_by_name['check_tx'].message_type = _RESPONSECHECKTX
_RESPONSEBROADCASTTX.fields_by_name['deliver_tx'].message_type = _RESPONSEDELIVERTX
DESCRIPTOR.message_types_by_name['KVPair'] = _KVPAIR
DESCRIPTOR.message_types_by_name['ProofOp'] = _PROOFOP
DESCRIPTOR.message_types_by_name['Proof'] = _PROOF
DESCRIPTOR.message_types_by_name['BlockParams'] = _BLOCKPARAMS
DESCRIPTOR.message_types_by_name['EvidenceParams'] = _EVIDENCEPARAMS
DESCRIPTOR.message_types_by_name['ValidatorParams'] = _VALIDATORPARAMS
DESCRIPTOR.message_types_by_name['ConsensusParams'] = _CONSENSUSPARAMS
DESCRIPTOR.message_types_by_name['LastCommitInfo'] = _LASTCOMMITINFO
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['BlockID'] = _BLOCKID
DESCRIPTOR.message_types_by_name['PartSetHeader'] = _PARTSETHEADER
DESCRIPTOR.message_types_by_name['Validator'] = _VALIDATOR
DESCRIPTOR.message_types_by_name['ValidatorUpdate'] = _VALIDATORUPDATE
DESCRIPTOR.message_types_by_name['VoteInfo'] = _VOTEINFO
DESCRIPTOR.message_types_by_name['PubKey'] = _PUBKEY
DESCRIPTOR.message_types_by_name['Evidence'] = _EVIDENCE
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['RequestEcho'] = _REQUESTECHO
DESCRIPTOR.message_types_by_name['RequestFlush'] = _REQUESTFLUSH
DESCRIPTOR.message_types_by_name['RequestInfo'] = _REQUESTINFO
DESCRIPTOR.message_types_by_name['RequestSetOption'] = _REQUESTSETOPTION
DESCRIPTOR.message_types_by_name['RequestInitChain'] = _REQUESTINITCHAIN
DESCRIPTOR.message_types_by_name['RequestQuery'] = _REQUESTQUERY
DESCRIPTOR.message_types_by_name['RequestBeginBlock'] = _REQUESTBEGINBLOCK
DESCRIPTOR.message_types_by_name['RequestCheckTx'] = _REQUESTCHECKTX
DESCRIPTOR.message_types_by_name['RequestDeliverTx'] = _REQUESTDELIVERTX
DESCRIPTOR.message_types_by_name['RequestEndBlock'] = _REQUESTENDBLOCK
DESCRIPTOR.message_types_by_name['RequestCommit'] = _REQUESTCOMMIT
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['ResponseException'] = _RESPONSEEXCEPTION
DESCRIPTOR.message_types_by_name['ResponseEcho'] = _RESPONSEECHO
DESCRIPTOR.message_types_by_name['ResponseFlush'] = _RESPONSEFLUSH
DESCRIPTOR.message_types_by_name['ResponseInfo'] = _RESPONSEINFO
DESCRIPTOR.message_types_by_name['ResponseSetOption'] = _RESPONSESETOPTION
DESCRIPTOR.message_types_by_name['ResponseInitChain'] = _RESPONSEINITCHAIN
DESCRIPTOR.message_types_by_name['ResponseQuery'] = _RESPONSEQUERY
DESCRIPTOR.message_types_by_name['ResponseBeginBlock'] = _RESPONSEBEGINBLOCK
DESCRIPTOR.message_types_by_name['ResponseCheckTx'] = _RESPONSECHECKTX
DESCRIPTOR.message_types_by_name['ResponseDeliverTx'] = _RESPONSEDELIVERTX
DESCRIPTOR.message_types_by_name['ResponseEndBlock'] = _RESPONSEENDBLOCK
DESCRIPTOR.message_types_by_name['ResponseCommit'] = _RESPONSECOMMIT
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['RequestPing'] = _REQUESTPING
DESCRIPTOR.message_types_by_name['RequestBroadcastTx'] = _REQUESTBROADCASTTX
DESCRIPTOR.message_types_by_name['ResponsePing'] = _RESPONSEPING
DESCRIPTOR.message_types_by_name['ResponseBroadcastTx'] = _RESPONSEBROADCASTTX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KVPair = _reflection.GeneratedProtocolMessageType('KVPair', (_message.Message,), dict(
    DESCRIPTOR=_KVPAIR,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.KVPair)
))
_sym_db.RegisterMessage(KVPair)

ProofOp = _reflection.GeneratedProtocolMessageType('ProofOp', (_message.Message,), dict(
    DESCRIPTOR=_PROOFOP,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ProofOp)
))
_sym_db.RegisterMessage(ProofOp)

Proof = _reflection.GeneratedProtocolMessageType('Proof', (_message.Message,), dict(
    DESCRIPTOR=_PROOF,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.Proof)
))
_sym_db.RegisterMessage(Proof)

BlockParams = _reflection.GeneratedProtocolMessageType('BlockParams', (_message.Message,), dict(
    DESCRIPTOR=_BLOCKPARAMS,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.BlockParams)
))
_sym_db.RegisterMessage(BlockParams)

EvidenceParams = _reflection.GeneratedProtocolMessageType('EvidenceParams', (_message.Message,), dict(
    DESCRIPTOR=_EVIDENCEPARAMS,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.EvidenceParams)
))
_sym_db.RegisterMessage(EvidenceParams)

ValidatorParams = _reflection.GeneratedProtocolMessageType('ValidatorParams', (_message.Message,), dict(
    DESCRIPTOR=_VALIDATORPARAMS,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ValidatorParams)
))
_sym_db.RegisterMessage(ValidatorParams)

ConsensusParams = _reflection.GeneratedProtocolMessageType('ConsensusParams', (_message.Message,), dict(
    DESCRIPTOR=_CONSENSUSPARAMS,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ConsensusParams)
))
_sym_db.RegisterMessage(ConsensusParams)

LastCommitInfo = _reflection.GeneratedProtocolMessageType('LastCommitInfo', (_message.Message,), dict(
    DESCRIPTOR=_LASTCOMMITINFO,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.LastCommitInfo)
))
_sym_db.RegisterMessage(LastCommitInfo)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), dict(
    DESCRIPTOR=_VERSION,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.Version)
))
_sym_db.RegisterMessage(Version)

BlockID = _reflection.GeneratedProtocolMessageType('BlockID', (_message.Message,), dict(
    DESCRIPTOR=_BLOCKID,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.BlockID)
))
_sym_db.RegisterMessage(BlockID)

PartSetHeader = _reflection.GeneratedProtocolMessageType('PartSetHeader', (_message.Message,), dict(
    DESCRIPTOR=_PARTSETHEADER,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.PartSetHeader)
))
_sym_db.RegisterMessage(PartSetHeader)

Validator = _reflection.GeneratedProtocolMessageType('Validator', (_message.Message,), dict(
    DESCRIPTOR=_VALIDATOR,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.Validator)
))
_sym_db.RegisterMessage(Validator)

ValidatorUpdate = _reflection.GeneratedProtocolMessageType('ValidatorUpdate', (_message.Message,), dict(
    DESCRIPTOR=_VALIDATORUPDATE,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ValidatorUpdate)
))
_sym_db.RegisterMessage(ValidatorUpdate)

VoteInfo = _reflection.GeneratedProtocolMessageType('VoteInfo', (_message.Message,), dict(
    DESCRIPTOR=_VOTEINFO,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.VoteInfo)
))
_sym_db.RegisterMessage(VoteInfo)

PubKey = _reflection.GeneratedProtocolMessageType('PubKey', (_message.Message,), dict(
    DESCRIPTOR=_PUBKEY,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.PubKey)
))
_sym_db.RegisterMessage(PubKey)

Evidence = _reflection.GeneratedProtocolMessageType('Evidence', (_message.Message,), dict(
    DESCRIPTOR=_EVIDENCE,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.Evidence)
))
_sym_db.RegisterMessage(Evidence)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
    DESCRIPTOR=_HEADER,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.Header)
))
_sym_db.RegisterMessage(Header)

RequestEcho = _reflection.GeneratedProtocolMessageType('RequestEcho', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTECHO,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestEcho)
))
_sym_db.RegisterMessage(RequestEcho)

RequestFlush = _reflection.GeneratedProtocolMessageType('RequestFlush', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTFLUSH,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestFlush)
))
_sym_db.RegisterMessage(RequestFlush)

RequestInfo = _reflection.GeneratedProtocolMessageType('RequestInfo', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTINFO,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestInfo)
))
_sym_db.RegisterMessage(RequestInfo)

RequestSetOption = _reflection.GeneratedProtocolMessageType('RequestSetOption', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTSETOPTION,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestSetOption)
))
_sym_db.RegisterMessage(RequestSetOption)

RequestInitChain = _reflection.GeneratedProtocolMessageType('RequestInitChain', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTINITCHAIN,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestInitChain)
))
_sym_db.RegisterMessage(RequestInitChain)

RequestQuery = _reflection.GeneratedProtocolMessageType('RequestQuery', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTQUERY,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestQuery)
))
_sym_db.RegisterMessage(RequestQuery)

RequestBeginBlock = _reflection.GeneratedProtocolMessageType('RequestBeginBlock', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTBEGINBLOCK,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestBeginBlock)
))
_sym_db.RegisterMessage(RequestBeginBlock)

RequestCheckTx = _reflection.GeneratedProtocolMessageType('RequestCheckTx', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTCHECKTX,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestCheckTx)
))
_sym_db.RegisterMessage(RequestCheckTx)

RequestDeliverTx = _reflection.GeneratedProtocolMessageType('RequestDeliverTx', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTDELIVERTX,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestDeliverTx)
))
_sym_db.RegisterMessage(RequestDeliverTx)

RequestEndBlock = _reflection.GeneratedProtocolMessageType('RequestEndBlock', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTENDBLOCK,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestEndBlock)
))
_sym_db.RegisterMessage(RequestEndBlock)

RequestCommit = _reflection.GeneratedProtocolMessageType('RequestCommit', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTCOMMIT,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestCommit)
))
_sym_db.RegisterMessage(RequestCommit)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), dict(
    DESCRIPTOR=_REQUEST,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.Request)
))
_sym_db.RegisterMessage(Request)

ResponseException = _reflection.GeneratedProtocolMessageType('ResponseException', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEEXCEPTION,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseException)
))
_sym_db.RegisterMessage(ResponseException)

ResponseEcho = _reflection.GeneratedProtocolMessageType('ResponseEcho', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEECHO,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseEcho)
))
_sym_db.RegisterMessage(ResponseEcho)

ResponseFlush = _reflection.GeneratedProtocolMessageType('ResponseFlush', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEFLUSH,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseFlush)
))
_sym_db.RegisterMessage(ResponseFlush)

ResponseInfo = _reflection.GeneratedProtocolMessageType('ResponseInfo', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEINFO,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseInfo)
))
_sym_db.RegisterMessage(ResponseInfo)

ResponseSetOption = _reflection.GeneratedProtocolMessageType('ResponseSetOption', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSESETOPTION,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseSetOption)
))
_sym_db.RegisterMessage(ResponseSetOption)

ResponseInitChain = _reflection.GeneratedProtocolMessageType('ResponseInitChain', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEINITCHAIN,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseInitChain)
))
_sym_db.RegisterMessage(ResponseInitChain)

ResponseQuery = _reflection.GeneratedProtocolMessageType('ResponseQuery', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEQUERY,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseQuery)
))
_sym_db.RegisterMessage(ResponseQuery)

ResponseBeginBlock = _reflection.GeneratedProtocolMessageType('ResponseBeginBlock', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEBEGINBLOCK,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseBeginBlock)
))
_sym_db.RegisterMessage(ResponseBeginBlock)

ResponseCheckTx = _reflection.GeneratedProtocolMessageType('ResponseCheckTx', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSECHECKTX,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseCheckTx)
))
_sym_db.RegisterMessage(ResponseCheckTx)

ResponseDeliverTx = _reflection.GeneratedProtocolMessageType('ResponseDeliverTx', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEDELIVERTX,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseDeliverTx)
))
_sym_db.RegisterMessage(ResponseDeliverTx)

ResponseEndBlock = _reflection.GeneratedProtocolMessageType('ResponseEndBlock', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEENDBLOCK,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseEndBlock)
))
_sym_db.RegisterMessage(ResponseEndBlock)

ResponseCommit = _reflection.GeneratedProtocolMessageType('ResponseCommit', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSECOMMIT,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseCommit)
))
_sym_db.RegisterMessage(ResponseCommit)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSE,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.Response)
))
_sym_db.RegisterMessage(Response)

RequestPing = _reflection.GeneratedProtocolMessageType('RequestPing', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTPING,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestPing)
))
_sym_db.RegisterMessage(RequestPing)

RequestBroadcastTx = _reflection.GeneratedProtocolMessageType('RequestBroadcastTx', (_message.Message,), dict(
    DESCRIPTOR=_REQUESTBROADCASTTX,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.RequestBroadcastTx)
))
_sym_db.RegisterMessage(RequestBroadcastTx)

ResponsePing = _reflection.GeneratedProtocolMessageType('ResponsePing', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEPING,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponsePing)
))
_sym_db.RegisterMessage(ResponsePing)

ResponseBroadcastTx = _reflection.GeneratedProtocolMessageType('ResponseBroadcastTx', (_message.Message,), dict(
    DESCRIPTOR=_RESPONSEBROADCASTTX,
    __module__='vendor_pb2'
    # @@protoc_insertion_point(class_scope:abci_vendor.ResponseBroadcastTx)
))
_sym_db.RegisterMessage(ResponseBroadcastTx)


_ABCIAPPLICATION = _descriptor.ServiceDescriptor(
    name='ABCIApplication',
    full_name='abci_vendor.ABCIApplication',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    serialized_start=4816,
    serialized_end=5600,
    methods=[
        _descriptor.MethodDescriptor(
            name='Echo',
            full_name='abci_vendor.ABCIApplication.Echo',
            index=0,
            containing_service=None,
            input_type=_REQUESTECHO,
            output_type=_RESPONSEECHO,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Flush',
            full_name='abci_vendor.ABCIApplication.Flush',
            index=1,
            containing_service=None,
            input_type=_REQUESTFLUSH,
            output_type=_RESPONSEFLUSH,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Info',
            full_name='abci_vendor.ABCIApplication.Info',
            index=2,
            containing_service=None,
            input_type=_REQUESTINFO,
            output_type=_RESPONSEINFO,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='SetOption',
            full_name='abci_vendor.ABCIApplication.SetOption',
            index=3,
            containing_service=None,
            input_type=_REQUESTSETOPTION,
            output_type=_RESPONSESETOPTION,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='DeliverTx',
            full_name='abci_vendor.ABCIApplication.DeliverTx',
            index=4,
            containing_service=None,
            input_type=_REQUESTDELIVERTX,
            output_type=_RESPONSEDELIVERTX,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='CheckTx',
            full_name='abci_vendor.ABCIApplication.CheckTx',
            index=5,
            containing_service=None,
            input_type=_REQUESTCHECKTX,
            output_type=_RESPONSECHECKTX,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Query',
            full_name='abci_vendor.ABCIApplication.Query',
            index=6,
            containing_service=None,
            input_type=_REQUESTQUERY,
            output_type=_RESPONSEQUERY,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='Commit',
            full_name='abci_vendor.ABCIApplication.Commit',
            index=7,
            containing_service=None,
            input_type=_REQUESTCOMMIT,
            output_type=_RESPONSECOMMIT,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='InitChain',
            full_name='abci_vendor.ABCIApplication.InitChain',
            index=8,
            containing_service=None,
            input_type=_REQUESTINITCHAIN,
            output_type=_RESPONSEINITCHAIN,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='BeginBlock',
            full_name='abci_vendor.ABCIApplication.BeginBlock',
            index=9,
            containing_service=None,
            input_type=_REQUESTBEGINBLOCK,
            output_type=_RESPONSEBEGINBLOCK,
            serialized_options=None,
        ),
        _descriptor.MethodDescriptor(
            name='EndBlock',
            full_name='abci_vendor.ABCIApplication.EndBlock',
            index=10,
            containing_service=None,
            input_type=_REQUESTENDBLOCK,
            output_type=_RESPONSEENDBLOCK,
            serialized_options=None,
        ),
    ])
_sym_db.RegisterServiceDescriptor(_ABCIAPPLICATION)

DESCRIPTOR.services_by_name['ABCIApplication'] = _ABCIAPPLICATION

# @@protoc_insertion_point(module_scope)



import ast
import unittest

from event_chain import protos
from event_chain.application import did_auth

from forge.utils import utils as forge_utils


class AuthRequestTest(unittest.TestCase):

    def setUp(self):
        args = {
            'from': 'z1bdvuibh8L9wG8Re5CZmyzrMYo7rjrV3i7',
            'nonce': 1,
            'pk': b'fakepk',
        }
        self.sample_tx = protos.Transaction(**args)

    def test_require_multisig(self):
        user_did = "z1bdvuibh8L9wG8Re5CZmyzrMYo7rjrV3i7"
        args = {
            'user_did': user_did,
            'tx': self.sample_tx,
            'url': 'http: // sample_url',
            'description': 'this is a test',
            'workflow': 'work-flow-test',
            'action': 'requestAuth'
        }

        response = did_auth.response_require_multisig(**args)

        body = forge_utils.b64encoded_to_dict(
            ast.literal_eval(response).get('authInfo').split('.')[1])

        assert (body.get('url') == 'http: // sample_url')
        assert(body.get('action') == 'requestAuth')
